@@ -8,7 +8,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2016 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -30,7 +30,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Platform/posix.py rel_2.4.0:3365:9259ea1c13d7 2015/09/21 14:03:43 bdbaddog"
+__revision__ = "src/engine/SCons/Platform/posix.py rel_2.5.1:3735:9dc6cee5c168 2016/11/03 14:02:02 bdbaddog"
 
 import errno
 import os
@@ -48,16 +48,18 @@ exitvalmap = {
 }
 
 def escape(arg):
-    "escape shell special characters"
+    "escape shell special characters" 
     slash = '\\'
-    special = '"$()'
+    special = '"$'
 
     arg = arg.replace(slash, slash+slash)
     for c in special:
         arg = arg.replace(c, slash+c)
 
+    # print "ESCAPE RESULT: %s"%arg
     return '"' + arg + '"'
 
+
 def exec_subprocess(l, env):
     proc = subprocess.Popen(l, env = env, close_fds = True)
     return proc.wait()
